@@ -17,10 +17,10 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.0.9'
+    version = '1.0.10'
     description = 'Send project error counts to DingDing .'
     resource_links = [
-        ('Source', 'https://github.com/cench/sentry-10-dingding'),
+        ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
         ('Bug Tracker', 'https://github.com/dreamerldq/sentry-dingding-format/issues'),
         ('README', 'https://github.com/dreamerldq/sentry-dingding-format/blob/master/README.md'),
     ]
@@ -63,7 +63,7 @@ class DingDingPlugin(NotificationPlugin):
                     device=event.get_tag('device'),
                     uid=event.get_tag('uid'),
                     path=event.get_tag('url'),
-                    event=str(event),
+                    event=json.dumps(event).encode("utf-8"),
                     message=event.title or event.message,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                 )
